# DecryptRSASignatureRequest


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**method** | **str** | The type of the request. Set it to Post.  | 
**public_key** | **str** | The public key generated by Zuora.  | 
**signature** | **str** | The signature generated by Zuora.  | 

## Example

```python
from zuora_sdk.models.decrypt_rsa_signature_request import DecryptRSASignatureRequest

# TODO update the JSON string below
json = "{}"
# create an instance of DecryptRSASignatureRequest from a JSON string
decrypt_rsa_signature_request_instance = DecryptRSASignatureRequest.from_json(json)
# print the JSON string representation of the object
print(DecryptRSASignatureRequest.to_json())

# convert the object into a dict
decrypt_rsa_signature_request_dict = decrypt_rsa_signature_request_instance.to_dict()
# create an instance of DecryptRSASignatureRequest from a dict
decrypt_rsa_signature_request_from_dict = DecryptRSASignatureRequest.from_dict(decrypt_rsa_signature_request_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


